==> libphidget22java-1.0.0.20170727.tar.gz: libphidget22java-1.0.0.20170727/src/jni/com_phidget22_IR.c <==
/*
 * This file is part of libphidget22java
 *
 * Copyright 2015 Phidgets Inc <patrick@phidgets.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see
 * <http://www.gnu.org/licenses/>
 */

#include "phidget_jni.h"
#include "com_phidget22_IR.h"
#include "com_phidget22_IRBase.h"

extern jfieldID phidget_handle_fid;

void com_phidget22_IR_OnLoad(JNIEnv *env) { }

JNIEXPORT jobject JNICALL Java_com_phidget22_IRBase_getLastCode(JNIEnv * env, jobject obj) {
	PhidgetIRHandle h = (PhidgetIRHandle)(uintptr_t)(*env)->GetLongField(env, obj, phidget_handle_fid);
	int error;
	char code[33];
	size_t codeLength = 33;
	uint32_t bitCount;
	IRCode irCode;
	if ((error = PhidgetIR_getLastCode(h, code, codeLength, &bitCount)))
		PH_THROW(error);
	irCode.bitCount = bitCount;
	irCode.code = code;
	return IRCode_to_jobject(env, &irCode);
}

JNIEXPORT jobject JNICALL Java_com_phidget22_IRBase_getLastLearnedCode(JNIEnv * env, jobject obj) {
	PhidgetIRHandle h = (PhidgetIRHandle)(uintptr_t)(*env)->GetLongField(env, obj, phidget_handle_fid);
	int error;
	char code[33];
	size_t codeLength = 33;
	IRLearnedCode irLearnedCode;
	if ((error = PhidgetIR_getLastLearnedCode(h, code, codeLength, &(irLearnedCode.codeInfo))))
		PH_THROW(error);
	irLearnedCode.code = code;
	return IRLearnedCode_to_jobject(env, &irLearnedCode);
}

==> libphidget22java-1.0.0.20180327.tar.gz: libphidget22java-1.0.0.20180327/src/jni/com_phidget22_IR.c <==
/*
 * This file is part of libphidget22java
 *
 * Copyright 2015 Phidgets Inc <patrick@phidgets.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see
 * <http://www.gnu.org/licenses/>
 */

#include "phidget_jni.h"
#include "com_phidget22_IR.h"
#include "com_phidget22_IRBase.h"

extern jfieldID phidget_handle_fid;

void com_phidget22_IR_OnLoad(JNIEnv *env) { }

JNIEXPORT jobject JNICALL Java_com_phidget22_IRBase_getLastCode(JNIEnv * env, jobject obj) {
	PhidgetIRHandle h = (PhidgetIRHandle)(uintptr_t)(*env)->GetLongField(env, obj, phidget_handle_fid);
	int error;
	char code[33];
	size_t codeLength = 33;
	uint32_t bitCount;
	IRCode irCode;
	if ((error = PhidgetIR_getLastCode(h, code, codeLength, &bitCount))) {
		PH_THROW(error);
		return NULL;
	}
	irCode.bitCount = bitCount;
	irCode.code = code;
	return IRCode_to_jobject(env, &irCode);
}

JNIEXPORT jobject JNICALL Java_com_phidget22_IRBase_getLastLearnedCode(JNIEnv * env, jobject obj) {
	PhidgetIRHandle h = (PhidgetIRHandle)(uintptr_t)(*env)->GetLongField(env, obj, phidget_handle_fid);
	int error;
	char code[33];
	size_t codeLength = 33;
	IRLearnedCode irLearnedCode;
	if ((error = PhidgetIR_getLastLearnedCode(h, code, codeLength, &(irLearnedCode.codeInfo)))) {
		PH_THROW(error);
		return NULL;
	}
	irLearnedCode.code = code;
	return IRLearnedCode_to_jobject(env, &irLearnedCode);
}
